"""cmsmanage URL Configuration

The `urlpatterns` list routes URLs to views. For more information please see:
    https://docs.djangoproject.com/en/3.1/topics/http/urls/
Examples:
Function views
    1. Add an import:  from my_app import views
    2. Add a URL to urlpatterns:  path('', views.home, name='home')
Class-based views
    1. Add an import:  from other_app.views import Home
    2. Add a URL to urlpatterns:  path('', Home.as_view(), name='home')
Including another URLconf
    1. Import the include() function: from django.urls import include, path
    2. Add a URL to urlpatterns:  path('blog/', include('blog.urls'))
"""

from django.conf import settings
from django.conf.urls.static import static
from django.contrib import admin
from django.contrib.auth.views import LoginView, LogoutView
from django.urls import include, path

from rest_framework import routers

from membershipworks.api import router as membershipworks_router
from paperwork.api import router as paperwork_router

from . import views

router = routers.DefaultRouter()
router.registry.extend(paperwork_router.registry)
router.registry.extend(membershipworks_router.registry)

urlpatterns = [
    path("", include("dashboard.urls")),
    # path("tasks/", include("tasks.urls")),
    path("rentals/", include("rentals.urls")),
    path("membershipworks/", include("membershipworks.urls")),
    path("paperwork/", include("paperwork.urls")),
    path("doorcontrol/", include("doorcontrol.urls")),
    path("api/v1/", include((router.urls, "api"), namespace="v1")),
    path("admin/", admin.site.urls),
    path(
        "auth/",
        include(
            [
                path(
                    "login/",
                    LoginView.as_view(
                        template_name="auth/login.dj.html",
                        redirect_authenticated_user=True,
                    ),
                    name="login",
                ),
                path(
                    "logout/",
                    LogoutView.as_view(template_name="auth/logout.dj.html"),
                    name="logout",
                ),
            ]
        ),
    ),
    path("api-auth/", include("rest_framework.urls")),
    path("healthcheck", views.healthcheck),
    # path("markdownx/", include("markdownx.urls")),
]

if settings.DEBUG:
    urlpatterns.append(path("__debug__/", include("debug_toolbar.urls")))
    urlpatterns += static(settings.MEDIA_URL, document_root=settings.MEDIA_ROOT)
