# Generated by Django 4.2.5 on 2023-09-19 04:20

import django.db.models.deletion
from django.db import migrations, models


def link_events_to_doors(apps, schema_editor):
    HIDEvent = apps.get_model("doorcontrol", "HIDEvent")
    Door = apps.get_model("doorcontrol", "Door")
    for event in HIDEvent.objects.all():
        door, created = Door.objects.get_or_create(name=event.door_name)
        event.door = door
        event.save()


class Migration(migrations.Migration):
    dependencies = [
        ("doorcontrol", "0001_initial"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="hidevent",
            options={"ordering": ("-timestamp",)},
        ),
        migrations.CreateModel(
            name="Door",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("name", models.CharField(max_length=64, unique=True)),
            ],
        ),
        # create nullable foreign key to door
        migrations.AddField(
            model_name="hidevent",
            name="door",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                to="doorcontrol.door",
                null=True,
            ),
        ),
        # create new Doors and link them to HID Events
        migrations.RunPython(link_events_to_doors, atomic=True),
        # make door foreign key not nullable
        migrations.AlterField(
            model_name="hidevent",
            name="door",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE, to="doorcontrol.door"
            ),
        ),
        # remove old constaint
        migrations.RemoveConstraint(model_name="hidevent", name="unique_hidevent"),
        # remove old name field
        migrations.RemoveField(
            model_name="hidevent",
            name="door_name",
        ),
        migrations.AddConstraint(
            model_name="hidevent",
            constraint=models.UniqueConstraint(
                fields=("door", "timestamp", "event_type"), name="unique_hidevent"
            ),
        ),
    ]
